#
# spec file for package health-checker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _dracutmoduledir %(pkg-config --variable=dracutmodulesdir dracut)

Name:           health-checker
Version:        1.12+git20241105.2e2832f15742
Release:        1.2
Summary:        Service for verifying that important services are running
License:        GPL-2.0-only
Group:          System/Base
URL:            https://github.com/kubic-project/health-checker
Source:         health-checker-%{version}.tar.xz
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  suse-module-tools
BuildRequires:  pkgconfig(dracut)
BuildRequires:  pkgconfig(systemd)
Requires:       health-checker-plugins = 1.0
BuildArch:      noarch

%description
health-checker is a service running once at every reboot to verify
that all important services are running. If it is the first reboot after
an update, an automatic rollback to the last working snapshot is made.
If this is not after an update, a reboot is made. If this does not help,
the services will be disabled.
This package does not contain any checks. For this, additional
plugins for different products are needed.

%package plugins-MicroOS
Summary:        Health-checker plugins for openSUSE MicroOS
Group:          System/Base
Requires:       %{name} >= %{version}
Provides:       health-checker-plugins = 1.0

%description plugins-MicroOS
This package contains health-checker plugins for testing that
the openSUSE MicroOS did boot correctly.

%package testing
Summary:        Test plugin for health-checker
Group:          System/Base
Requires:       %{name} >= %{version}
Provides:       health-checker-plugins = 1.0

%description testing
This package contains a script for testing the CaaSP health checker.
It will report success or failures depending on previous states.

%prep
%setup -q -n health-checker-%{version}

%build
./autogen.sh
%configure
make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}%{_mandir}

%pre
%service_add_pre health-checker.service

%post
%service_add_post health-checker.service
%regenerate_initrd_post

%preun
%service_del_preun health-checker.service

%postun
%service_del_postun health-checker.service
%regenerate_initrd_post

%posttrans
%regenerate_initrd_posttrans

%files
%license COPYING
%doc NEWS README.md
%{_unitdir}/health-checker.service
%dir %{_libexecdir}/health-checker/
%{_libexecdir}/health-checker/btrfs-subvolumes-mounted.sh
%{_libexecdir}/health-checker/logind.sh
%{_libexecdir}/health-checker/rpmdb-consistency.sh
%{_libexecdir}/health-checker/tmp.sh
%{_sbindir}/health-checker
%{_mandir}/man8/health-checker.8%{?ext_man}
%{_mandir}/man8/health-checker.service.8%{?ext_man}
%dir %{_sysconfdir}/grub.d
%{_sysconfdir}/grub.d/*_health_check*
%{_dracutmoduledir}/50health-checker

%files plugins-MicroOS
%{_libexecdir}/health-checker/etc-overlayfs.sh
%{_libexecdir}/health-checker/rebootmgr.sh

%files testing
%{_libexecdir}/health-checker/health-check-tester.sh

%changelog
* Tue Nov  5 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 1.12+git20241105.2e2832f15742:
  * Set RemainAfterExit=yes
  * Fix header of NEWS file
- Switch _service over to obs_scm and type="manual"
* Wed Sep 25 2024 iforster@suse.com
- Update to version 1.12+git20240925.08fb1bc:
  * Release version 1.12
  * Fix typos: replaced `health-checker.state` occurances with
    `health-check.state` (#23)
  * Improve rpmdb consistency check (#21)
  * Drop crio, etcd and kubelet
  * Implement missing stop argument
- Remove plugins-kubic and plugins-caasp packages - the tests were
  removed upstream because the products were EOL
* Tue Jul 30 2024 iforster@suse.com
- Update to version 1.11+git20240730.5dafd6a:
  * Add rpm db consistency plugin
* Thu Jun 20 2024 Thorsten Kukuk <kukuk@suse.com>
- Remove rchealth-checker symlink [jsc#PED-264]
* Thu Jan 11 2024 kukuk@suse.com
- Update to version 1.10+git20240111.cb84209:
  * Add missing rule for health-checker.service.8
  * Don't generate html documentation
  * Fixing some typo's and improving the UX of the health-checker output
  * Fix a typo in README.md
* Fri Sep 15 2023 Ignaz Forster <iforster@suse.com>
- Update to version 1.10
  * Fix Btrfs subvolume check if subvol starts with '-'
    [boo#1215368].
* Thu Jun 22 2023 Ignaz Forster <iforster@suse.com>
- Update to version 1.9
  * Fix failing subvolume mount checks with certain characters in
    mount point [gh#openSUSE/health-checker#14].
* Mon May  8 2023 Ignaz Forster <iforster@suse.com>
- Update to version 1.8
  * Don't rely on t-u's good states in GRUB
    With the introduction of the "apply" command in
    transactional-update the snapshots don't require a reboot any
    more to be registered as a "good" snapshot. Due to
    [boo#1048088] the GRUB part of health-checker was using the t-u
    file as a workaround which cannot be done any more now, so
    store the last good snapshot path from a health-checker
    perspective independently now.
* Tue Sep  6 2022 Ignaz Forster <iforster@suse.com>
- Update to version 1.7
  * Before rollback make sure /.snapshots is mounted rw
  * Fix typos and spelling errors. Note: in case an application is
    parsing the output it will need to adopt to the new strings.
* Fri Nov 12 2021 Ignaz Forster <iforster@suse.com>
- Update to version 1.6
  * Adapt rd.retry to also trigger initqueue timeout tasks
    [gh#kubic-project/health-checker#11]
  * Reboot system and let the GRUB health-checker part try to find
    a working initrd if root file system could not be mounted -
    instead of ending up in an emergency shell
  * Correctly declare Bash scripts as such
* Tue Jul 13 2021 Stefan Schubert <schubi@suse.com
- Added /usr/local/libexec/health-checker for user defined plugins.
* Wed Aug 19 2020 Ignaz Forster <iforster@suse.com>
- Update to version 1.4
  * Add checks for /tmp and systemd-logind
  * Build system cleanup
* Tue May 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use the right variables for systemd unitdir and dracut modules
  directory.
* Tue May 12 2020 Ignaz Forster <iforster@suse.com>
- Update to version 1.3.4
  * Really fix plugindir replacement in configure.ac script
* Fri May  8 2020 Ignaz Forster <iforster@suse.com>
- Update to version 1.3.3
  * Fix plugindir replacement in configure.ac script
  * Use Python 3 for building documentation
* Wed May  6 2020 Ignaz Forster <iforster@suse.com>
- Use pkgconfig macro instead of package dependencies
* Wed May  6 2020 Ignaz Forster <iforster@suse.com>
- Update to version 1.3.2
  * Use pkgconf to determine installation directories instead of
    guessing
* Thu Jan 30 2020 Ignaz Forster <iforster@suse.com>
- Update to version 1.3.1
  * Support multiple menuentries in GRUB configuration
    [gh#kubic-project/health-checker#5]
* Mon Dec 16 2019 Ignaz Forster <iforster@suse.com>
- Update to version 1.3
  * Support /var on non-root device for reading health data
  * Avoid GRUB error message if env_block is not set [boo#1151072]
  * Don't show message on manual emergency shell invocation
  * Fix handling when booting a non-default snapshot
* Mon May  6 2019 kukuk@suse.de
- Update to version 1.2.3
  * Fix crio RPM name
* Wed Mar 20 2019 kukuk@suse.de
- Update to version 1.2.2
  * Fix product namings
* Thu Mar 14 2019 kukuk@suse.de
- Update to version 1.2.1
  * Make sure telmetrics payload is not empty in success case
* Wed Feb 27 2019 kukuk@suse.de
- Update to version 1.2
  * Add hooks to send telemetrics events
* Mon Feb  4 2019 kukuk@suse.de
- Update to version 1.1
  * new plugins for crio and kubelet
- Add new sub-package with test cases for openSUSE Kubic
* Wed Dec 19 2018 kukuk@suse.de
- Split the CaaSP plugin into a MicroOS and CaaSP part
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Wed May 23 2018 kukuk@suse.de
- Update to version 1.0
  * Skip health checker if emergency shell started by user
  * Add GRUB2 fallback handling
  * Adapt to new unified /var directory.
  * Get basic version of rollback from initrd working
* Wed Aug 23 2017 kukuk@suse.de
- Update to version 0.5
  - Fix logger arguments
* Thu May 25 2017 jengelh@inai.de
- Resolve orthographical issues in descriptions.
* Thu May 18 2017 kukuk@suse.de
- Update to version 0.4
- Rename package to health-checker
- Create new sub-package for CaaSP plugins
* Fri Mar 24 2017 kukuk@suse.de
- Update to version 0.2
  - Add plugins for etcd, etc-overlayfs and rebootmgr
* Thu Mar 23 2017 kukuk@suse.de
- Initial version
